==> phplist-2.10.5p0.tgz: lists/admin/lan/pt-br/message.php <==
<?php
$lan = array(
 'Please select a message to display' => 'Por favor, selecione uma mensage para ser exibida',
 'Attachments for this message' => 'Anexos para esta mensagem',
 'No attachments' => 'Nenhum anexo',
 'Filename' => 'Nome do arquivo',
 'Size' => 'Tamanho',
 'Mime Type' => 'Tipo de Mime',
 'Description' => 'Descri&ccedil;&atilde;o',
 'Lists this message has been sent to' => 'Listas para as quais esta mensagem foi enviada',
 'None yet' => 'Nenhuma ainda',
 'Send this (same) message to (a) new list(s)' => 'Enviar esta (mesma) mensagem para outra(s) lista(s)',
 'List is Active' => 'A lista est&acute; ativa',
 'List is not Active' => 'A lista n&atilde;o est&acute; ativa',
 '<b>Note:</b> this message has already been sent to all lists. To resend it to new users use the "Requeue" function.' => '<b>Aviso:</b> esta mensagem j&acute; foi enviada para todas as listas. Para reenvi&acute;-la aos novos usu&acute;rios use a fun&ccedil;&atilde;o "Realinhamento".',
 'Resend' => 'Reenviar',
 'id' => 'id',
 'subject' => 'assunto',
 'fromfield' => 'campo de',
 'tofield' => 'campo para',
 'replyto' => 'responder para',
 'message' => 'mensagem',
 'textmessage' => 'mesagem texto',
 'footer' => 'rodap&eacute;',
 'entered' => 'inserido',
 'modified' => 'modificado',
 'embargo' => 'bloqueada',
 'repeatinterval' => 'repetir intervalo',
 'repeatuntil' => 'repetir at&eacute;',
 'status' => 'estatus',
 'userselection' => 'sele&ccedil;&atilde;o de usu&aacute;rio',
 'sent' => 'enviado',
 'htmlformatted' => 'formtado em html',
 'sendformat' => 'formato de envio',
 'template' => 'modelo',
 'processed' => 'processado',
 'astext' => 'como text',
 'ashtml' => 'como html',
// 'astextandhtml' => 'como texto e html', //obsolete by bug 0009687
 'aspdf' => 'como pdf',
 'astextandpdf' => 'como texto e pdf',
 'viewed' => 'exibida',
 'bouncecount' => 'contador de emails com problema',
 'sendstart' => 'envio iniciado',
 'rsstemplate' => 'modelo RSS',
 'owner' => 'administrador',
);
?>

==> phplist-2.10.14p1.tgz: lists/admin/lan/pt-br/message.php <==
<?php
$lan = array(
 'Please select a message to display' => 'Por favor, selecione a mensagem para ser exibida',
 'Edit this message' => 'Editar mensagem',
 'No such message' => 'Mensagem n&atilde;o encontrada',
 'Attachments for this message' => 'Anexos para esta mensagem',
 'No attachments' => 'Nenhum anexo',
 'Filename' => 'Nome do arquivo',
 'Size' => 'Tamanho',
 'Mime Type' => 'Tipo de Mime',
 'Description' => 'Descri&ccedil;&atilde;o',
 'Lists this message has been sent to' => 'Listas para as quais esta mensagem foi enviada',
 'None yet' => 'Nenhuma ainda',
 'Send this (same) message to (a) new list(s)' => 'Enviar esta (mesma) mensagem para outra(s) lista(s)',
 'List is Active' => 'A lista est&aacute; ativa',
 'List is not Active' => 'A lista n&atilde;o est&aacute; ativa',
 '<b>Note:</b> this message has already been sent to all lists. To resend it to new users use the "Requeue" function.' => '<b>Aviso:</b> esta mensagem j&aacute; foi enviada para todas as listas. Para reenvi&aacute;-la a novos usu&aacute;rios, use a fun&ccedil;&atilde;o "Redistribuir".',
 'Resend' => 'Reenviar',
 'id' => 'id',
 'subject' => 'assunto',
 'fromfield' => 'campo de',
 'tofield' => 'campo para',
 'replyto' => 'responder para',
 'message' => 'mensagem',
 'textmessage' => 'mesagem texto',
 'footer' => 'rodap&eacute;',
 'entered' => 'inserido',
 'modified' => 'modificado',
 'embargo' => 'bloqueada',
 'repeatinterval' => 'repetir intervalo',
 'repeatuntil' => 'repetir at&eacute;',
 'status' => 'estatus',
 'userselection' => 'sele&ccedil;&atilde;o de usu&aacute;rio',
 'sent' => 'enviado',
 'htmlformatted' => 'formtado em html',
 'sendformat' => 'formato de envio',
 'template' => 'modelo',
 'processed' => 'processado',
 'astext' => 'como text',
 'ashtml' => 'como html',
// 'astextandhtml' => 'como texto e html', //obsolete by bug 0009687
 'aspdf' => 'como pdf',
 'astextandpdf' => 'como texto e pdf',
 'viewed' => 'exibida',
 'bouncecount' => 'contador de emails com problema',
 'sendstart' => 'envio iniciado',
 'rsstemplate' => 'modelo RSS',
 'owner' => 'administrador',
);
?>
